@@ -1,6 +1,8 @@
 SITE_ID = 1
-ROOT_URLCONF = 'demoproject.urls'
+STATIC_URL = '/static/'
+ROOT_URLCONF = 'concurrency.tests.urls'
 SECRET_KEY = ';klkj;okj;lkn;lklj;lkj;kjmlliuewhy2ioqwjdkh'
+
 INSTALLED_APPS = (
     'concurrency',
     'django.contrib.auth',
@@ -10,7 +12,6 @@ INSTALLED_APPS = (
     'django.contrib.messages',
     'django.contrib.staticfiles',
     'django.contrib.admin',
-
 )
 
 DATABASES = {
